@@ -8,13 +8,15 @@ NULL
 #' @param when \code{\link{POSIXct-class}} for date and time on which the variable \code{x} is requested. 
 #' @param layers number of soil layer or geotop keyword for soil layer (e.g. \code{SoilLayerThicknesses} or \code{SoilFile}). Default is  \code{SoilLayerThicknesses}. 
 #' @param timestep time step expressed in seconds every which the raster file has been created. It can be a string corresponding to the geotop keyword in the inpts file. Default value is \code{"OutputSoilMaps"}.
-#' @param suffix charachter string containing the decimal formatter used by GEOtop in the output file names. Default is "L\%04dN\%04.asc". A simple user is recommended not to modify the value of this argument and use the default value.
+#' @param suffix charachter string containing the decimal formatter used by GEOtop in the output file names. Default is \code{"L\%04dN\%04.asc"}. A simple user is recommended not to modify the value of this argument and use the default value.
+#' @param time_formatter,suffix_one.layer  charachter string  (\code{suffix_one.layer} is used for 2Dxy map) containing the decimal formatter used by GEOtop in the output file names to indicate time instant. Default is \code{"N\%04.asc"}. A simple user is recommended not to modify the value of this argument and use the default value.
 #' @param wpath,tz,use.read.raster.from.url see \code{\link{get.geotop.inpts.keyword.value}}
 #' @param projfile  name of the \code{*.proj} file containing CRS information. See \code{\link{get.geotop.inpts.keyword.value}}. Default is \code{"geotop.proj"}. If is \code{NULL} or \code{NA} or this file does not exist, it is not searched and read.. In case \code{use.read.raster.from.url} is \code{TRUE} and no \code{NULL} or \code{NA} values are assinged, the \code{*.proj} file is searched. 
 #' @param crs,start.from.zero see \code{\link{brick.decimal.formatter}}. If \code{crs} is not \code{NULL} (Default) , \code{projfile} is ignored.
 #' @param one.layer logical value. If \code{TRUE} a \code{\link{RasterLayer-class}} object is imported, otherwise a \code{\link{RasterBrick-class}}object is returened. Default for \code{brickFromOutputSoil3DTensor} is \code{FALSE}
 #' @param start_date_key,end_date_key initial and final detes and times of the GEOtop simulation or alternatively the respective keywords of \code{*.inpts} file (Default) 
 #' @param secondary.suffix String secondary suffix which can be added at the end of the Map file name (optional). Default is \code{NULL} and no secondary suffix is added.  
+#' @param only.map.filename logical value. If it is \code{TRUE}, only map file names are returned and maps are not imported. Default is \code{FALSE}.
 #' @param ... additional arguments for \code{\link{get.geotop.inpts.keyword.value}} or \code{\link{brickFromOutputSoil3DTensor}}
 #'  
 #' @rdname brickFromOutputSoil3DTensor
@@ -162,7 +164,7 @@ NULL
 #
 #SoilLiqWaterPressTensorFile 
 #
-#
+
 #
 #SoilTempTensorFile Name of the ensamble of raster maps corresponding to the temperature
 #of each layer (if PlotSoilDepth6=0 it writes the value at the corresponding
@@ -183,7 +185,7 @@ NULL
 
 
 
-brickFromOutputSoil3DTensor <- function(x,when,layers="SoilLayerThicknesses",one.layer=FALSE,suffix="L%04dN%04d.asc",wpath=NULL,tz="A",start_date_key="InitDateDDMMYYYYhhmm",end_date_key="EndDateDDMMYYYYhhmm",timestep="OutputSoilMaps",use.read.raster.from.url=FALSE,crs=NULL,projfile="geotop.proj",start.from.zero=FALSE,secondary.suffix=NULL,...) {
+brickFromOutputSoil3DTensor <- function(x,when,layers="SoilLayerThicknesses",one.layer=FALSE,suffix="L%04dN%04d.asc",time_formatter="N%04d",suffix_one.layer="N%04d.asc",wpath=NULL,tz="A",start_date_key="InitDateDDMMYYYYhhmm",end_date_key="EndDateDDMMYYYYhhmm",timestep="OutputSoilMaps",use.read.raster.from.url=FALSE,crs=NULL,projfile="geotop.proj",start.from.zero=FALSE,secondary.suffix=NULL,only.map.filename=FALSE,...) {
 	
 	out <- NULL
 
@@ -208,11 +210,11 @@ brickFromOutputSoil3DTensor <- function(x,when,layers="SoilLayerThicknesses",one
 	
 	
 	
-	start_s <- get.geotop.inpts.keyword.value(start_date_key,date=TRUE,wpath=wpath,tz=tz,...) ###wpath=wpath,tz="A")
-	end_s <- get.geotop.inpts.keyword.value(end_date_key,date=TRUE,wpath=wpath,tz=tz,...) ###wpath=wpath,tz="A")
+	start_s <- geotopbricks::get.geotop.inpts.keyword.value(start_date_key,date=TRUE,wpath=wpath,tz=tz,...) ###wpath=wpath,tz="A")
+	end_s <- geotopbricks::get.geotop.inpts.keyword.value(end_date_key,date=TRUE,wpath=wpath,tz=tz,...) ###wpath=wpath,tz="A")
 	
 	
-	if (!is.numeric(timestep)) timestep <- get.geotop.inpts.keyword.value(timestep,wpath=wpath,numeric=TRUE,...)*3600 
+	if (!is.numeric(timestep)) timestep <- geotopbricks::get.geotop.inpts.keyword.value(timestep,wpath=wpath,numeric=TRUE,...)*3600 
 	
 	time <- seq(from=start_s,to=end_s,by=timestep)
 	
@@ -228,26 +230,43 @@ brickFromOutputSoil3DTensor <- function(x,when,layers="SoilLayerThicknesses",one
 		if (layers=="SoilLayerThicknesses") {
 		
 			###get.geotop.inpts.keyword.value("SoilLayerThicknesses",numeric=TRUE,wpath=wpath,...)
-			layers <- get.geotop.inpts.keyword.value("SoilLayerThicknesses",numeric=TRUE,wpath=wpath,...) ####wpath=wpath)
+			layers <- geotopbricks::get.geotop.inpts.keyword.value("SoilLayerThicknesses",numeric=TRUE,wpath=wpath,...) ####wpath=wpath)
 			###print(layers)
 			if (is.null(layers)) {
 				layers <-  "SoilParFile"
 			} else {
 				
-				#layers <- 1:length(layers)
+		#		layers <- 1:length(layers)
 			}	
 				
 		} 
 		
 		if (layers[1]=="SoilParFile") {
 			
-			layers <- get.geotop.inpts.keyword.value("SoilParFile",wpath=wpath,add_wpath=TRUE,data.frame=TRUE,level=1,date_field=NULL,...)$Dz
+			
+			headerDz <- geotopbricks::get.geotop.inpts.keyword.value("HeaderSoilDz",wpath=wpath,...)[1]
+			if (is.null(headerDz)) headerDz <- "Dz"
+			layers <- geotopbricks::get.geotop.inpts.keyword.value("SoilParFile",wpath=wpath,add_wpath=TRUE,data.frame=TRUE,level=1,date_field=NULL,...)[,headerDz]
 			
 		
 			
 
-		} else if (!is.numeric(layers)) {
+		} 
+		
+		
+		if (!is.numeric(layers) | (length(layers)==1)) {
+		
+		### SoilLayerNumber
 			
+			nl <- geotopbricks::get.geotop.inpts.keyword.value("SoilLayerNumber",numeric=TRUE,wpath=wpath,...)[1]
+			if (!is.null(nl)) layers <- 1:nl
+		
+		} 
+		
+		
+		if (!is.numeric(layers)) {
+			
+			warning("Layers Not Numeric 1:2 by Defalut!")
 			layers <- 1:2
 			
 		}
@@ -255,7 +274,7 @@ brickFromOutputSoil3DTensor <- function(x,when,layers="SoilLayerThicknesses",one
 		
 	}
 	
-	map.prefix <- get.geotop.inpts.keyword.value(x,numeric=FALSE,date=FALSE,wpath=wpath,add_wpath=TRUE,...)
+	map.prefix <- geotopbricks::get.geotop.inpts.keyword.value(x,numeric=FALSE,date=FALSE,wpath=wpath,add_wpath=TRUE,...)
 	
 	
 	if (!is.null(secondary.suffix)) {
@@ -269,11 +288,15 @@ brickFromOutputSoil3DTensor <- function(x,when,layers="SoilLayerThicknesses",one
 	
 	
 	print(paste("Maps to import:",length(when),"from",as.character(when[1]),"to",as.character(when[length(when)]),sep=" "))
-	
+	message("Important bug solved from 1.3.7.3, previous versions (<= 1.3.7.2) could return slightly different results!")
+	time <- time[-1]
 	out <- lapply(X=when,FUN=function(whenx,map.prefix,suffix,crs,layers,start.from.zero,one.layer,time,timestep) {
 		
-		print(paste("Importing",as.character(whenx),sep=" "))
-		t_index <- abs(whenx-time)<timestep
+		message(paste("Importing",as.character(whenx),sep=" "))
+		
+		t_index <- abs(as.numeric((whenx-time),units="secs"))<timestep
+	
+		
 		index <- 1
 		n <- which(t_index)[index]
 				
@@ -286,21 +309,38 @@ brickFromOutputSoil3DTensor <- function(x,when,layers="SoilLayerThicknesses",one
 				
 		if (!is.na(n)) {
 		
-			suffix <- str_split(suffix,"N")[[1]]
-			suffix[2] <- sprintf(suffix[2],n)
-		
+			##
+			##  
+			##
+			##
+			#suffix <- str_split(suffix,"N")[[1]]
+			#suffix[2] <- sprintf(suffix[2],n)
+			time_formatter_n <- sprintf(time_formatter,n)
+			
 			if (one.layer) {
 		
-				suffix <- paste("N",suffix[2],sep="")
+				suffix <- str_replace(suffix_one.layer,time_formatter,time_formatter_n)
+			## rc 20151218
+			
+			#####	suffix <- paste("N",suffix[2],sep="")
 			
 			
 			} else {	
-				suffix <- paste(suffix,collapse="N")
+				
+				suffix <- str_replace(suffix,time_formatter,time_formatter_n)
+			#######	suffix <- str_replace(suffix,time_formatter,time_formatter_n)
+				
+				####suffix <- paste(suffix,collapse="N")
 			}	
 		
 			map.filename <- paste(map.prefix,suffix,sep="")
+			message(paste("As ",as.character(time[n]),sep=" "))
 		
-			if (one.layer) {
+			if (only.map.filename==TRUE) {
+			
+				out <- map.filename
+			
+			} else if (one.layer) {
 			
 				if (use.read.raster.from.url) {				
 					out <- read.raster.from.url(x=map.filename)
@@ -314,7 +354,8 @@ brickFromOutputSoil3DTensor <- function(x,when,layers="SoilLayerThicknesses",one
 			
 			
 			} else {
-			
+				
+				
 				out <- brick.decimal.formatter(map.filename,nlayers=length(layers),use.read.raster.from.url=use.read.raster.from.url,start.from.zero=start.from.zero,crs=crs)
 		
 				if (start.from.zero) {
@@ -358,7 +399,7 @@ NULL
 rasterFromOutput2DMap <- function(x,when,...) {
 	
 	
-	out <- brickFromOutputSoil3DTensor(x=x,when=when,layers=1,one.layer=TRUE,...)
+	out <- geotopbricks::brickFromOutputSoil3DTensor(x=x,when=when,layers=1,one.layer=TRUE,...)
 	return(out)
 	
 }
